clear
set more off
set mem 500m

*Generating 00_ETH_BASICINFO.dta*

cd "C:\AFRCE\Ethiopia 2000"
use "02_CLEANDATA\ur20_1st.dta", clear

des /*79,622 observations*/

*Individual level dataset*

sort HID
codebook HID /*17,332 Hhouseholds*/

*Generating REGION variable*
*-----------------------------
rename killil REGION
recode REGION (12=8) (13=9) (14=10) (15=11)
label def REGION 1 "Tigray" 2 "Afar" 3 "Amhara" 4 "Oromiya" 5"Somali" 6 "Benishangul" 7 "SNNPRG" 8 "Gambela" 9 "Harari" 10 "Addis Ababa" 11 "Dire Dawa"

*Generating RURURB variable*
*-----------------------------
recode ur (1=2) (2=1)
rename ur RURURB
lab val RURURB RURURB
lab def RURURB 1 "Rural" 2 "Urban"


*Generating HHSIZE_S variable*
*------------------------------
gen HHSIZE_S=hhld_siz
*660 missing values generated*

drop if HHSIZE_S==.
*660 observations are dropped because they don't have information on sex and also household size*

*Generating HHSIZE(excluding maids and servants)variable*
*---------------------------------------------------------

*relation" variable does not contain maids and servants category*
*However, since maids and servants are not relatives,they could be in the non-relatives category*
*Therefore,non-relatives category is used to calculate "HHSIZE" variable*

bysort HID: egen HHSIZE=count(sex) if relation!=8

sort HID

count  /*78,962 observations*/

save "04_AGGDATA\temp1.dta",replace
*----------------------------------------

use "02_CLEANDATA\hhice.dta", clear

des /*1,205,438 observations*/

*item level dataset*

sort HID
codebook HID /*17,332 Hhouseholds*/

*Generating WTA_HH variable*
*----------------------------
gen WTA_HH=wgt

bysort HID: keep if _n==1

count  /*17,332 households*/

*Merging HHSIZE_S from "04_AGGDATA\temp1.dta"*
*-----------------------------------------------
sort HID
merge HID using "04_AGGDATA\temp1.dta"
tab _merge  /*_merge=1 (660 observations),_merge=3 (78,962 observations)*/
drop if _merge==1
drop _merge

*Generating WTA_POP variable*
*-----------------------------
gen WTA_POP=WTA_HH*HHSIZE_S

collapse REGION RURURB HHSIZE HHSIZE_S WTA_POP WTA_HH, by (HID)

*Generating COUNTRY variable*
*-----------------------------
gen COUNTRY = "ETH"
lab var COUNTRY "country name"

*Generating SURVEYR variable* 
*-----------------------------
gen SURVEYR = 2000

label var HID "Household unique ID"

label var RURURB "Area of residence"

label val SURVEYR SURVEYR
label var SURVEYR "Survey year"

label val HHSIZE_S HHSIZE_S
label var HHSIZE_S "Total number of residents including maids and servants"

label val HHSIZE HHSIZE
label var HHSIZE "Total number of residents excluding maids and servants"

lab val WTA_HH WTA_HH
lab var WTA_HH "Household weight"

lab val WTA_POP WTA_POP
lab var WTA_POP "Population weight"

order COUNTRY REGION HID SURVEYR RURURB HHSIZE HHSIZE_S WTA_HH WTA_POP

count  /*16,672 observations (households)*/

sort HID

save "04_AGGDATA\00_ETH_BASICINFO", replace

erase "04_AGGDATA\temp1.dta"



