clear
set more off
set mem 500m

*Generating 04_ETH_EXPHOUS.dta*
*-------------------------------

cd "C:\AFRCE\Ethiopia 2000"
use "02_CLEANDATA\hhice.dta", clear

des /* observations*/
codebook HID  /*17,332 househilds*/

*Generating RENT_ACT variable*
*-------------------------------
gen RENT_ACT=expend if [item3==30101|item3==30103|item3==90305]

*Generating RENT_IMP variable*
*--------------------------------
gen RENT_IMP=expend if [item3==30102|item3==30104]

*Generating HSREPAIR variable*
*--------------------------------
gen HSREPAIR=expend if item3==30105
replace HSREPAIR=expend if item3>=30201 & item3<=30298

*Generating HSWATER variable*
*-----------------------------
gen HSWATER=expend if item3==30301

*Generating HSFULEL*
*----------------------
gen HSFUEL=expend if [item3>=30401 & item3<=30405]
replace HSFUEL=expend if item3==30412

*Generating GAS variable*
*-------------------------
gen GAS=expend if item3==30410

*Generating ELEC variable*
*-----------------------------
gen ELEC=expend if item3==30407

*Generating HSKEROSENE variable*
*-----------------------------------
gen HSKEROSENE=expend if item3==30406

*Generating HSDIESEL variable*
*---------------------------------
gen HSDIESEL=.

*Generating HSUTILITY variable*
*---------------------------------
egen HSUTILITY=rowtotal (GAS ELEC)

collapse (sum) RENT_ACT RENT_IMP HSREPAIR HSWATER HSFUEL GAS ELEC HSKEROSENE HSDIESEL HSUTILITY, by (HID)

des /*Total # of observations is 17,332 (households)*/
*----------------------------------------------------------------------------------

*Merging with 00_ETH_BASICINFO*
*-------------------------------
sort HID
merge HID using "04_AGGDATA\00_ETH_BASICINFO.dta", keep (RURURB)
tab _merge  /*_merge=1 (660 observations),_merge=3 (16,672 observations)*/
drop if _merge==1
drop _merge

des /*16,672 observations (households)*/

*Annualizing the variables*
*-----------------------------
*expenditure values are already annualized in the dataset*

*Generating TOTHOUS variable*
*-------------------------------
egen TOTHOUS =rowtotal(HSREPAIR HSWATER HSFUEL HSKEROSENE HSDIESEL HSUTILITY)

*Labeling the variables*
*------------------------
lab val RENT_ACT RENT_ACT
label var RENT_ACT "Actual rentals for housing"

lab val RENT_IMP RENT_IMP
label var RENT_IMP "Imputed rentals for housing - SAME AS OWNER OCCUPIED HOUSING RENT"

lab val HSREPAIR HSREPAIR
label var HSREPAIR "Expenditure on maintenance and repair of dwelling"

lab val HSWATER HSWATER
label var HSWATER "Expenditure on water supply and miscellaneous services related to dwelling"

lab val HSFUEL HSFUEL
label var HSFUEL "Expenditure on firewood charcoal and other fuel"

lab val GAS GAS
label var GAS "Expenditure on gas for cooking"

lab val ELEC ELEC
label var ELEC "Expenditure on electricity"

lab val HSKEROSENE HSKEROSENE
label var HSKEROSENE "Expenditure on kerosine"

lab val HSDIESEL HSDIESEL
label var HSDIESEL "Expenditure on diesel"

lab val HSUTILITY HSUTILITY
label var HSUTILITY "Expenditure on electricity and gas (rowtoal of GAS and ELEC)"

lab val TOTHOUS TOTHOUS
label var TOTHOUS "Total expenditure on housing"

order HID RURURB RENT_ACT RENT_IMP HSREPAIR HSWATER HSFUEL GAS ELEC HSKEROSENE HSDIESEL HSUTILITY TOTHOUS

des /*number of observations is 16,672*/

sort HID

save "04_AGGDATA\04_ETH_EXPHOUS", replace







