*Standardized Household Level File*
*-----------------------------------
                 
*Generating ETH_2000_H.dta*
*-----------------------------

*Section 3.1:Sample,Geography and Basic Household Identifier *
*--------------------------------------------------------------

clear
set more off
set mem 500m

cd "C:\AFRCE\Ethiopia 2000"
use "02_CLEANDATA\hhice.dta", clear

des  /*initial number of observations is 1,205,438*/

sort HID
codebook HID /*17,332 households*/

*Generating DISTRICT variable*
*------------------------------
gen DISTRICT=c104
lab val DISTRICT DISTRICT
lab var DISTRICT "District code"

*Generating PROVINCE variable*
*-------------------------------
rename c102 PROVINCE
recode PROVINCE (12=8) (13=9) (14=10) (15=11)
label def PROVINCE 1 "Tigray" 2 "Afar" 3 "Amhara" 4 "Oromiya" 5"Somali" 6 "Benishangul" 7 "SNNPRG" 8 "Gambela" 9 "Harari" 10 "Addis Ababa" 11 "Dire Dawa",replace
lab val PROVINCE PROVINCE
lab var PROVINCE "Province code"

keep HID DISTRICT PROVINCE

sort HID

collapse DISTRICT PROVINCE,by (HID)

des  /*17,332 observations (households)*/

*Merging with 00_ETH_BASICINFO.dta*
*------------------------------------
sort HID
merge HID using 04_AGGDATA\00_ETH_BASICINFO.dta, keep (COUNTRY REGION SURVEYR RURURB HHSIZE HHSIZE_S WTA_HH WTA_POP)
tab _merge /*_merge=1 (660 observations), _merge=3 (16,672 observations)*/
drop if _merge==1
drop _merge

count /*16,672 observations (households)*/

order COUNTRY REGION PROVINCE DISTRICT HID SURVEYR RURURB HHSIZE HHSIZE_S WTA_HH WTA_POP

sort HID

save 04_AGGDATA\ETH_2000_H.dta, replace
*----------------------------------------------------------------------------------------------

*Section 3.2:Household Head Characteristics*
*-------------------------------------------

use 04_AGGDATA\ETH_2000_I, clear

count /*78,962 observations*/

keep HID SEX AGEY MARSTAT EDLEVEL_AR HEAD 
drop if HEAD!=1
drop HEAD

count /*16,672 observations*/

rename SEX HHSEX
rename AGEY HHAGEY
rename MARSTAT HHMARST
rename EDLEVEL_AR HHEDLEV

lab var HHSEX "Sex of household head"
lab var HHAGEY "Age of household head"
lab var HHMARST "Marital status of household head"
lab var HHEDLEV "Education level of household head"

sort HID

*Merging above variables with 04_AGGDATA\ETH_2000_H.dta*
*---------------------------------------------------------
merge HID using 04_AGGDATA\ETH_2000_H.dta

tab _merge  /*_merge=3 (16,672 observations)*/
drop _merge

count /*16,672 observations (households)*/

sort HID

save 04_AGGDATA\ETH_2000_H.dta, replace
*----------------------------------------------------------------------------------------------

*Section 3.3: Housing and Utilities*
*-------------------------------------

use "02_CLEANDATA\ur20_2nd.dta", clear

des   /*initial number of observations is 17,332*/

sort HID
codebook HID  /*17,332 households*/

*dataset is at the household level*

*Generating OWNHOUSE variable*
*-------------------------------
gen OWNHOUSE=.
replace OWNHOUSE=1 if dwellin1==0
replace OWNHOUSE=0 if [dwellin1==1|dwellin1==2|dwellin1==3|dwellin1==4|dwellin1==5|dwellin1==6|dwellin1==7|dwellin1==8|dwellin1==9]
lab val OWNHOUSE OWNHOUSE
lab def OWNHOUSE 1 "Yes" 0 "No",replace
lab var OWNHOUSE "Ownership of dwelling unit"

*Generating ROOMS variable*
*----------------------------
*NOTE:there is no variable in the dataset that can distinguish the different types of rooms in dwelling unit such as living room, bedroom, kitchen etc*
gen	ROOMS=.	
lab var ROOMS "Number of habitable rooms"

*Generating ROOF variable*
*---------------------------
gen ROOF=.
replace ROOF=2 if roof1==3 
*above category in "roof" variable includes roof made out of mud as well since in roof1 variable, wood and mud roofs are aggrgated together to form roof1==3*
replace ROOF=3 if roof1==4 
replace ROOF=9 if [roof1==1|roof1==2|roof1==5]
lab val ROOF ROOF
lab def ROOF 1 " Concrete/cement/brick/stone" 2 "Wood" 3 "bamboo/thach" 4 "Tiles/shingles" 5 "Tin/metal sheets" 6 "Makeshift" 9 "other",replace
lab var ROOF "Main material used for roof"	

*Generating WALLS variable*
*----------------------------
gen WALLS=.
replace WALLS=1 if [wall1==4|wall1==5|wall1==7]
*above category also includes mud since wall1=4 aggregates mud with stone*
replace WALLS=2 if [wall1==1|wall1==2]
*above category in "walls" variable includes wood aggregated with mud and thatch since in wall1 variable the wood is aggregated with other materials*
replace WALLS=3 if wall1==3
replace WALLS=9 if 	[wall1==6|wall1==8]				
lab val WALLS WALLS
lab def WALLS 1 " Concrete/cement/brick/stone" 2 "Wood" 3 "Bamboo/thach" 4 "Iron/metal sheets" 5 "Clay/mud" 6 "Makeshift" 9 "other",replace
lab var WALLS "Main material used for external walls"					

*Generating FLOOR variable*
*---------------------------
gen FLOOR=.
lab val FLOOR FLOOR
lab def FLOOR 1 "Cement/tiles/marble" 2 "Wood/Bamboo" 3 "Vinyl" 4 "Earth/clay/mud" 9 "Other"
lab var FLOOR "Main material used for floor"

*Generating WATER variable*
*----------------------------
*NOTE:dataset contains source of drinking water in both wet and dry season*
*"WATER" variable will be derived from soure of drinking water in dry season(wat_dry1) because most of Ethiopia's regions have dry season*
gen WATER=.
replace WATER=1 if [wat_dry1==1|wat_dry1==2]
replace WATER=2 if [wat_dry1==3|wat_dry1==4]
replace WATER=4 if wat_dry1==5
replace WATER=5 if wat_dry1==6
replace WATER=6 if wat_dry1==7
lab val WATER WATER
lab def WATER 1 "Pipe (own tap)" 2 "Public standpipe" 3 "Borehole" 4 "Wells(protected)" 5 "Wells(unprotected)" 6 "Surface water" 7 "Rain water" 8 "Vendor/truck" 9 "Other"
lab var WATER "Main source of water"

*Generating ADISWAT variable*
*------------------------------
*NOTE:dataset contains drinking water in both wet and dry season. "adiswat" variable will be derived from variable "distan10" because most of Ethiopia's regions have dry season*
gen ADISWAT=distan10
lab val ADISWAT ADISWAT
lab var ADISWAT "Actual distance to main water point (kms)"

*Generating ATIMWAT variable*
*-------------------------------
gen ATIMWAT=.
lab val ATIMWAT ATIMWAT
lab var ATIMWAT "Actual time taken to main water point (mins)"

*Generating ELECTCON variable*
*-------------------------------
gen ELECTCON=.
lab val ELECTCON ELECTCON
lab def ELECTCON 1 "Central/local" 2 "Solar/wind" 3 "Generator" 9 "Other" 0 "None"
lab var ELECTCON "Connection of electricity in dwelling"

*Generating FUELCOOK variable*
*-------------------------------
gen FUELCOOK=.
replace FUELCOOK=1 if [fuelcoo1==1|fuelcoo1==2]
replace FUELCOOK=2 if fuelcoo1==4
replace FUELCOOK=3 if fuelcoo1==3
replace FUELCOOK=4 if fuelcoo1==6
replace FUELCOOK=5 if fuelcoo1==5
replace FUELCOOK=9 if [fuelcoo1==7|fuelcoo1==8]
*w5q22a==8 not included in fuelcook==9 because w5q22a==8 is "no source of cooking fuel used now"*/
lab val FUELCOOK FUELCOOK
lab def FUELCOOK 1 "Firewood" 2 "Kerosene" 3 "Charcoal" 4 "Electricity" 5 "Gas" 9 "Other"
lab var FUELCOOK "Main cooking fuel"

*Generating FUELLIGH variable*
*-------------------------------
gen FUELLIGH=.
replace FUELLIGH=1 if [lightin1==2|lightin1==3]
replace FUELLIGH=2 if lightin1==1
replace FUELLIGH=3 if lightin1==5
replace FUELLIGH=9 if [lightin1==4|lightin1==6]
lab val FUELLIGH FUELLIGH
lab def FUELLIGH 1 "Electricity" 2 "Kerosene" 3 "Candles" 4 "Gas" 9 "Other"
lab var FUELLIGH "Main lighting fuel"

*Generating TOILET variable*
*------------------------------
gen TOILET=.
replace TOILET=1 if [toilet1==1|toilet1==2]
replace TOILET=3 if [toilet1==3|toilet1==4]
replace TOILET=9 if [toilet1==5|toilet1==6|toilet1==7]
lab val TOILET TOILET
lab def TOILET 1 "Flush toilet" 2 "Improved pit latrine" 3 "Pit latrine" 4 "No facility" 9 "Other"
lab var TOILET "Main toilet facility"

*Generating GARBDISP variable*
*-------------------------------
gen GARBDISP=.
lab val GARBDISP GARBDISP
lab def GARBDISP 1 "Collected" 2 "Buried/burned" 3 "Discarded in empty lots,street,rivers" 9 "Other"
lab var GARBDISP "Garbage and trash disposal"

*Generating DISPSCH variable*
*------------------------------
gen DISPSCH=distanc3 
*no indication in dataset whether "distanc3" variable is a one-way or two-way distance*
*so assume reported distance is a one way distance inorder to avoid loss of information"
lab val DISPSCH DISPSCH
lab var DISPSCH "Distance to nearest elementary/primary school(kms)"

*Generating DISPSCH1*
*----------------------
*no indication in the dataset on whether reported distance is a one or two way distance*
*So assume reported distance is a one-way distance inorder to avoid loss of information*
gen DISPSCH1=.
replace DISPSCH1=1 if [distanc3==0|distanc3==1]
replace DISPSCH1=2 if distanc3>2
replace DISPSCH1=3 if distanc3>5
replace DISPSCH1=4 if distanc3>10
replace DISPSCH1=5 if distanc3>11
lab val DISPSCH1 DISPSCH1
lab def DISPSCH1 1 "Outside dwelling and up to 1 km" 2 ">1-2 km" 3 ">2-5 km" 4 ">5-10 km" 5 "over 10 km" 9 "Undefined"
lab var DISPSCH1 "Distance to nearest elementary school"

*Generating TIMPSCH variable*
*------------------------------
gen TIMPSCH=.
lab val TIMPSCH TIMPSCH
lab var TIMPSCH "Time taken to nearest elementary/primary school (mins)"
 
*Generating TIMPSCH1 variable*
*--------------------------------
gen TIMPSCH1=. 
lab val TIMPSCH1 TIMPSCH1
lab def TIMPSCH1 1 "Within 1/2 hour" 2 ">1/2 to 1 hour away" 3 ">1 to 6 hrs" 4 ">6 to 12 hrs" 5 "Over 12 hrs" 9 "Undefined"
lab var TIMPSCH1 "Time taken to nearest elementary/primary school"

*Generating DISHEAL variable*
*-------------------------------
gen DISHEAL=distanc5
lab val DISHEAL DISHEAL
lab var DISHEAL "Distance to nearest health facility (kms)"

*Generating DISHEAL1 variable*
*---------------------------------
 *NOTE:distance measure in the dataset has no decimals, therefore,the cut-off points used in generating dispsch1 is different from what is stated in the reference mannual*
 *However, the variable is coded according to the reference manual to keep harmony with other surveys*/ 
gen DISHEAL1=.
replace DISHEAL1=1 if [distanc5==0|distanc5==1]
replace DISHEAL1=2 if distanc5>2
replace DISHEAL1=3 if distanc5>5
replace DISHEAL1=4 if distanc5>10
replace DISHEAL1=5 if distanc5>11
lab val DISHEAL1 DISHEAL1
lab def DISHEAL1 1 "Outside dwelling and up to 1 km" 2 ">1-2 km" 3 ">2-5 km" 4 ">5-10 km" 5 "Over 10 km" 9 "Undefined"
lab var DISHEAL1 "Dstance to nearest health facility"

*Generating TIMHEAL variable*
*-------------------------------
gen TIMHEAL=. 
lab val TIMHEAL TIMHEAL
lab var TIMHEAL "Time taken to nearest health facility (mins)"

*Generating TIMHEAL1 variable*
*-------------------------------
gen TIMHEAL1=. 
lab val TIMHEAL1 TIMHEAL1
lab def TIMHEAL1 1 "Within 1/2 hour" 2 ">1/2 to 1 hour away" 3 ">1 to 6 hrs" 4 ">6 to 12 hrs" 5 "over 12 hrs" 9 "Undefined"
lab var TIMHEAL1 "Time taken to nearest health facility"

keep HID OWNHOUSE ROOMS ROOF WALLS FLOOR WATER ADISWAT ATIMWAT ELECTCON FUELCOOK ///
	FUELLIGH TOILET GARBDISP DISPSCH DISPSCH1 TIMPSCH TIMPSCH1 DISHEAL DISHEAL1 TIMHEAL TIMHEAL1 ///

*Merging with 04_AGGDATA\ETH_2000_H.dta*
*------------------------------------------
sort HID
merge HID using 04_AGGDATA\ETH_2000_H.dta
tab _merge  /*_merge=1 (660 observations),_merge=3 (16,672 observations)*/
drop if _merge==1
drop _merge

count /*16,672 observations (households)*/

sort HID

save 04_AGGDATA\ETH_2000_H.dta, replace
*--------------------------------------------------------------------------------------------		

*Section 3.5: Ownership of Durable and Non-Durable Goods*					
*--------------------------------------------------------

use "02_CLEANDATA\ur20_2nd.dta", clear

des  /*initial number of observations is 17,332*/

codebook HID /*17,332 households*/

*dataset is at the household level*
				
*Generating AGLAND variable*
*----------------------------
gen AGLAND=2 
*type of land is not specified in the dataset, therefore, agland coded as 2 as required by the reference manual*
lab val AGLAND AGLAND
lab def AGLAND 1 "Yes" 2 "Cannot be determined" 3 "No"
lab var AGLAND "Ownership of agricultural land"

*Generating AGLNDOW variable*
*-----------------------------
*AGLNDOW generated as a variable will all missing observations since AGLAND=2*
gen AGLNDOW=.
lab val AGLNDOW AGLNDOW 
lab var AGLNDOW "Agricultural land owned by household(ha)"

*Generating OTHLNDOW variable*
*-------------------------------
gen OTHLNDOW=.
lab val OTHLNDOW OTHLNDOW
lab var OTHLNDOW "Non-agricultural land owned by household (ha)"

*Generating LANDSIZE variable*
*------------------------------
gen LANDSIZE=.
lab val LANDSIZE LANDSIZE
lab var LANDSIZE "Land size owned by household (ha)"

*Generating AREA_IRRIG variable*
*---------------------------------
gen AREA_IRRIG=.
lab val AREA_IRRIG AREA_IRRIG
lab var AREA_IRRIG "Area of irrigated agricultural land (ha)"

*Generating AREA_NONIRRIG variable*
*-------------------------------------
gen AREA_NONIRRIG=.
lab val AREA_NONIRRIG AREA_NONIRRIG
lab var AREA_NONIRRIG "Area of non-irrigated agricultural land (ha)"

*Generating AREA_COLLAT variable*			
*-----------------------------------
gen AREA_COLLAT=.
lab val AREA_COLLAT AREA_COLLAT
lab var AREA_COLLAT "Total plot areas can be used as collateral for loan (ha)"

*Generating LANDCON variable*
*-------------------------------
gen LANDCON=.
lab val LANDCON LANDCON
lab var LANDCON "Conflict about the land"

*Generating RADIO variable*
*-----------------------------
gen RADIO=.
replace RADIO=1 if doyouh17==1
replace RADIO=0 if doyouh17==2
lab val RADIO RADIO
lab def RADIO 1 "Yes" 0 "No",replace
lab var RADIO "ownership of radio"

*Generating TV variable*
*-------------------------
gen TV=.
replace TV=1 if doyouh21==1
replace TV=0 if doyouh21==2
lab val TV TV
lab def TV 1 "Yes" 0 "No",replace
lab var TV "Ownership of television"
					
*Generating PHONE variable*
*----------------------------
gen PHONE=.
lab val PHONE PHONE
lab def PHONE 0 "No" 1 "Yes"
lab var PHONE "Ownership of landline (fixed) phone"

*Generating CPHONE variable*
*------------------------------
gen CPHONE=.
lab val CPHONE CPHONE
lab def CPHONE 0 "No" 1 "Yes"
lab var CPHONE "Ownership of at least one cellular phone"

*Generating INTERNET variable*
*--------------------------------
gen INTERNET=.
lab val INTERNET INTERNET
lab def INTERNET 0 "No" 1 "Yes"
lab var INTERNET "Access to internet"

*Generating FRIDGE variable*
*-----------------------------
gen FRIDGE=.
replace FRIDGE=1 if doyouh23==1
replace FRIDGE=0 if doyouh23==2
lab val FRIDGE FRIDGE
lab def FRIDGE 0 "No" 1 "Yes" 
lab var FRIDGE "Ownership of fridge"  

*Generating SEWMACH variable*
*-------------------------------
gen SEWMACH=.
replace SEWMACH=1 if doyouh15==1
replace SEWMACH=0 if doyouh15==2
lab val SEWMACH SEWMACH
lab def SEWMACH 1 "Yes" 0 "No"
lab var SEWMACH "Ownership of sewing machine"  

*Generating COMPUTER variable*
*-------------------------------
gen COMPUTER=.
lab val COMPUTER COMPUTER
lab def COMPUTER 0 "No" 1 "Yes"
lab var COMPUTER "Ownership of computer"

*Generating STOVE variable*
*-----------------------------
gen STOVE=.
replace STOVE=1 if doyouh24==1
replace STOVE=0 if doyouh24==2
lab val STOVE STOVE
lab def STOVE 1 "Yes" 0 "No"
lab var STOVE "Ownership of stove"  			
					
*Generating OXCART variable*
*-----------------------------
gen OXCART=.
lab val OXCART OXCART
lab def OXCART 1 "Yes" 0 "No"
lab var OXCART "Ownership of animal cart" 

*Generating BCYCLE variable*
*------------------------------
gen BCYCLE=.
replace BCYCLE=1 if doyouh13==1
replace BCYCLE=0 if doyouh13==2
lab val BCYCLE BCYCLE
lab def BCYCLE 1 "Yes" 0 "No"
lab var BCYCLE "Ownership of bicycle" 

*Generating BOAT variable*
*--------------------------
gen BOAT=.
lab val BOAT BOAT
lab def BOAT 0 "No" 1 "Yes"
lab var BOAT "Ownership of boat"

*Generating MCYCLE variable*
*-----------------------------
gen MCYCLE=.
replace MCYCLE=1 if doyouh20==1
replace MCYCLE=0 if doyouh20==2
lab val MCYCLE MCYCLE
lab def MCYCLE 1 "Yes" 0 "No"
lab var MCYCLE "Ownership of bicycle" 

*Generating CAR variable*
*-------------------------
gen CAR=.
lab val CAR CAR
lab def CAR 0 "No" 1 "Yes"
lab var CAR "Ownership of private car"

*Generating LLIVESK variable*
*-----------------------------
gen LLIVESK=.
lab val LLIVESK LLIVESK
lab var LLIVESK "Number of large-sized livestock owned"

*Generating MLIVESK variable*
*-------------------------------
gen MLIVESK=numbero3
lab val MLIVESK MLIVESK
lab var MLIVESK "Number of medium-sized livestock owned"

*Generating POULTRY variable*
*------------------------------
gen POULTRY=numbero4
lab val POULTRY POULTRY
lab var POULTRY "Number of poultry owned"

keep HID AGLAND AGLNDOW OTHLNDOW LANDSIZE AREA_IRRIG AREA_NONIRRIG AREA_COLLAT ///
	LANDCON RADIO TV PHONE CPHONE INTERNET FRIDGE SEWMACH COMPUTER STOVE OXCART ///
	BCYCLE BOAT MCYCLE CAR LLIVESK MLIVESK POULTRY ///

*Merging with 04_AGGDATA\ETH_2000_H.dta*
*------------------------------------------
sort HID
merge HID using 04_AGGDATA\ETH_2000_H.dta
tab _merge  /*_merge=1 (660 observations),_merge=3 (16,672 observations)*/
drop if _merge==1
drop _merge

count  /*16,672 observations (households)*/
sort HID
save 04_AGGDATA\ETH_2000_H.dta, replace

*----------------------------------------------------------------------------------------------

*Section 3.5: Household Expenditure*		
*-------------------------------------
use "04_AGGDATA\ETH_2000_E.dta", clear
des  /*16,672 observations*/

*Generating PCEXP variable*
*-----------------------------
gen PCEXP=HHEXP_N/HHSIZE  
lab val PCEXP PCEXP
lab var PCEXP "Per capita annual food and non-food consumption expenditure in national currency, not regionally deflated"

*Generating PCEXPDR variable*
*--------------------------------
/*In the case of Ethiopia 2000 dataset, food expenditure cannot be adjusted regionally
due to non-availability of price deflator*
However, non-food expenditures are not regionally adjusted since rural and 
urban prices of non-food items are assumed to be the same across regions*/

*Generating Per-capita Food Expenditures*
*-------------------------------------------
gen PC_TOTFDAL=TOTFDAL/HHSIZE
lab val PC_TOTFDAL PC_TOTFDAL
lab var PC_TOTFDAL "Per capita food expenditures"

*Cleaning Per-capita Food Expenditures*
*---------------------------------------
egen Z_PC_TOTFDAL=std(PC_TOTFDAL)
bysort REGION RURURB:egen MD_PC_TOTFDAL=median(PC_TOTFDAL)
replace PC_TOTFDAL=MD_PC_TOTFDAL if Z_PC_TOTFDAL>3
drop Z_PC_TOTFDAL MD_PC_TOTFDAL
*if value is greater than 3 std dev, then it is replace by median value*

*Generating Per-capita Non-food Expenditures*
*---------------------------------------------
gen PC_TOTNFD=TOTNFD/HHSIZE
lab val PC_TOTNFD PC_TOTNFD
lab var PC_TOTNFD "Per capita non-food expenditures"

*Cleaning Per-capita Non-food Expenditures*
*--------------------------------------------
egen Z_PC_TOTNFD=std(PC_TOTNFD)
bysort REGION RURURB:egen MD_PC_TOTNFD=median(PC_TOTNFD)
replace PC_TOTNFD=MD_PC_TOTNFD if Z_PC_TOTNFD>3
drop Z_PC_TOTNFD MD_PC_TOTNFD

*Generating PCEXP_PPP*
*-----------------------
gen PCEXP_PPP=PCEXP*CPI2005_DEF*(1/PPP2005)

*CPI2005_DEF=CPI2005/CPI2000(Survey Year)*
/*CPI2005=277.565286,CPI 2000(survey year CPI)=236.3870268, 2005 PPP Exchange rate as per ICP Global Results=2.75*/

lab val  PCEXP_PPP  PCEXP_PPP
lab var  PCEXP_PPP "Per capita annual food and non-food cons. expend in real terms and 2005 $PPP"

drop PC_TOTFDAL PC_TOTFDAL PC_TOTNFD

keep HID PCEXP PCEXP_PPP

sort HID

des  /*16,672 observations*/

merge HID using "04_AGGDATA\ETH_2000_H.dta"
tab _merge   /*_merge=3 (16,672 observations)*/
drop _merge

*Generating QUINTILE_N variable*
*--------------------------------
xtile QUINTILE_N=PCEXP_PPP[aw=WTA_POP],nq(5)
lab val QUINTILE_N QUINTILE_N
lab var QUINTILE_N "Income quintiles at the national level"

*Generating QUINTILE_RU variable*
*-----------------------------------
xtile QUINTILE_RUR=PCEXP_PPP if RURURB==1[aw=WTA_POP],nq(5)
xtile QUINTILE_URB=PCEXP_PPP if RURURB==2[aw=WTA_POP],nq(5)
gen QUINTILE_R_U=QUINTILE_RUR if RURURB==1
replace QUINTILE_R_U=QUINTILE_URB if RURURB==2
lab val QUINTILE_R_U QUINTILE_R_U
label var QUINTILE_R_U" Expenditure quintiles by rural/urban"

count /*16,672 households*/

sort HID

save "04_AGGDATA\ETH_2000_H.dta",replace
*-----------------------------------------------------------------------------------------------

*Section 3.6: Household Remittances*
*------------------------------------

use "02_CLEANDATA\ur20_2nd.dta"

des  /*initial number of observations is 17,332*/

codebook HID /*17,332 households*/

*dataset is at the household level*

*Generating SEX_RMT_1 variable*
*-------------------------------
gen SEX_RMT_1=. 
lab val SEX_RMT_1 SEX_RMT_1
lab def SEX_RMT_1 1 "Male" 0 "Female"
lab var SEX_RMT_1 "Sex of the 1st remittance sending member"

*Generating SEX_RMT_2 variable*
*--------------------------------
gen SEX_RMT_2=.
lab val SEX_RMT_2 SEX_RMT_2
lab def SEX_RMT_2 1 "Male" 0 "Female"
lab var SEX_RMT_2 "Sex of the 2nd remittance sending member"

*Generating SEX_RMT_3 variable*
*-------------------------------
gen SEX_RMT_3=.
lab val SEX_RMT_3 SEX_RMT_3
lab def SEX_RMT_3 1 "Male" 0 "Female"
lab var SEX_RMT_3 "Sex of the 3rd remittance sending member"

*Generating RELAT_RMT_1 variable*
*----------------------------------
gen RELAT_RMT_1 =.
lab val RELAT_RMT_1 RELAT_RMT_1
lab def RELAT_RMT_1 2 "Spouse" 3 "Son/daughter" 4 "Parents/grandparents" 5 "Grandchild" 6 "Son/daughter-in-law" 7 "Siblings and other relative"
lab var RELAT_RMT_1 "Relationship to the household head of the 1st remittance sending member"

*Generating RELAT_RMT_2 variable*
*----------------------------------
gen RELAT_RMT_2 =.
lab val RELAT_RMT_2 RELAT_RMT_2
lab def RELAT_RMT_2 2 "Spouse" 3 "Son/daughter" 4 "Parents/grandparents" 5 "Grandchild" 6 "Son/daughter-in-law" 7 "Siblings and other relative"
lab var RELAT_RMT_2 "Relationship to the household head of the 2nd remittance sending member"

*Generating RELAT_RMT_3 variable*
*---------------------------------
gen RELAT_RMT_3 =.
lab val RELAT_RMT_3 RELAT_RMT_3
lab def RELAT_RMT_3 2 "Spouse" 3 "Son/daughter" 4 "Parents/grandparents" 5 "Grandchild" 6 "Son/daughter-in-law" 7 "Siblings and other relative"
lab var RELAT_RMT_3 "Relationship to the household head of the 3rd remittance sending member"

*Generating DES_MIG_1 variable*
*--------------------------------
gen DES_MIG_1=.
lab val DES_MIG_1 DES_MIG_1
lab def DES_MIG_1 1 "Capital" 2 "Within the country (but not capital" 3 "Abroad"
lab var DES_MIG_1 "Destination of migration of the 1st remittance sending member"

*Generating DES_MIG_2 variable*
*--------------------------------
gen DES_MIG_2=.
lab val DES_MIG_2 DES_MIG_2
lab def DES_MIG_2 1 "Capital" 2 "Within the country (but not capital" 3 "Abroad"
lab var DES_MIG_2 "Destination of migration of the 2nd remittance sending member"

*Generating DES_MIG_3 variable*
*-------------------------------
gen DES_MIG_3=.
lab val DES_MIG_3 DES_MIG_3
lab def DES_MIG_3 1 "Capital" 2 "Within the country (but not capital" 3 "Abroad"
lab var DES_MIG_3 "Destination of migration of the 3rd remittance sending member"

*Generating ORIGIN_RMT variable*
*-----------------------------------
gen ORIGIN_RMT=.
lab val ORIGIN_RMT ORIGIN_RMT
lab def ORIGIN_RMT 1 "Domestic"2 "Abroad" 3 "Both"
lab var  ORIGIN_RMT "Origin of the remittances"

*Generating AMT_RMT_1 variable*
*-------------------------------
gen AMT_RMT_1=.
lab val AMT_RMT_1 AMT_RMT_1
lab var AMT_RMT_1 "Amount of annual remittance by the 1st remittance sending member"

*Generating AMT_RMT_2 variable*
*--------------------------------
gen AMT_RMT_2=.
lab val AMT_RMT_2 AMT_RMT_2
lab var AMT_RMT_2 "Amount of annual remittance by the 2nd remittance sending member"

*Generating AMT_RMT_3 variable*
*-------------------------------
gen AMT_RMT_3=.
lab val AMT_RMT_3 AMT_RMT_3
lab var AMT_RMT_3 "Amount of annual remittance by the 3rd remittance sending member"

*Generating INC_RMT*
*----------------------
*"mnthin18" variable used to generate INC_RMT variable also includes income given as a gift*
gen INC_RMT=mnthin18*12
lab val INC_RMT INC_RMT
lab var INC_RMT "Total amount of annual remittances received from remittance sending members"

keep HID SEX_RMT_1 SEX_RMT_2 SEX_RMT_3 RELAT_RMT_1 RELAT_RMT_2 RELAT_RMT_3 DES_MIG_1 DES_MIG_2 DES_MIG_3 ORIGIN_RMT AMT_RMT_1 AMT_RMT_2 AMT_RMT_3 INC_RMT

*Merging with 04_AGGDATA\ETH_2000_H.dta*
*----------------------------------------
sort HID
merge HID using 04_AGGDATA\ETH_2000_H.dta
tab _merge  /*_merge=1 (660 observations),_merge=3 (17,332 observations)*/
drop if _merge==1
drop _merge

count  /*16,672 observations (households)*/

sort HID

save 04_AGGDATA\ETH_2000_H.dta, replace
*-------------------------------------------------------------------------------------------

*Section 3.7: Household Income Variables*
*----------------------------------------

use "02_CLEANDATA\ur20_2nd.dta"

des  /*initial number of observations is 17,332*/

codebook HID /*17,332 households*/

*dataset is at the household level*

*this dataset contains variables capturing income from various sources*
*income from the various sources are reported both for the last one month and six month*
*income from last one month will be used since a shorter recall period has a relatively higher reporting accuracy than a longer recall period*

*1)Adding income in last one month derived from sale of agricultural crops and then annualizing*
egen income_crop=rowtotal (mnthinc1  mnthinc2 mnthinc3 mnthinc4 mnthinc5 mnthinc6 mnthinc7 mnthinc8 mnthinc9 mnthin10)
replace income_crop=income_crop*12

*2)Adding income in last one month derived from sale of livestock products and fish*
egen income_livfish=rowtotal (mnthin11 mnthin12)
replace income_livfish=income_livfish*12

*3)Annualizing income from sale of other agricultural activities*
gen inc_othagri=mnthin13*12
 
*4)Annualizing income from household enterprise*
gen inc_hhent=mnthin14*12

*5)Adding wages and salaries from private and public sector and then annualizing*
egen wagesalary=rowtotal (mnthin15 mnthin16)
replace wagesalary=wagesalary*12

*6)Annualizing income from rent of house or machinery*
gen rent=mnthin17*12

*7)Anualizing income from gift and remittances*
gen grem=mnthin18*12

*8)Annualizing income from pension or insurance*
gen penins=mnthin19*12

*9)Annualizing income from other sources*
gen incother=mnthin20*12

*Generating INC_WAGE variable*
*------------------------------
gen INC_WAGE=wagesalary 
lab val INC_WAGE INC_WAGE
lab var INC_WAGE "Wage and salaries (annual)"

*Generating INC_SOCA variable*
*-------------------------------
gen INC_SOCA=. 
lab val INC_SOCA INC_SOCA
lab var INC_SOCA "Bonus and social allowances derived from wage jobs (annual)"

*Generating INC_FARM_G*
*------------------------
egen INC_FARM_G=rowtotal (income_crop income_livfish inc_othagri)
lab val INC_FARM_G INC_FARM_G
lab var INC_FARM_G "Gross income from household farm businesses (annual)"

*Generating INC_NFARM_G variable*
*---------------------------------
*"mnthin14" variable used to derive inc_hhent*
*"mnthin14" does not indicate whether the household enterprise is a farm or nonfarm business*
gen INC_NFARM_G=inc_hhent
lab val INC_NFARM_G INC_NFARM_G
lab var INC_NFARM_G "Gross income from household nonfarm businesses (annual)"

*Generating INC_RENT variable*
*--------------------------------
*"rent" variable includes income from renting machinery as well as dervied from "mnthin17" variable*
gen INC_RENT=rent
lab val INC_RENT INC_RENT
lab var INC_RENT "Rental income (annual)" 

*Generating INC_FIN variable*
*-----------------------------
gen INC_FIN=.
lab val INC_FIN INC_FIN
lab var INC_FIN "Financial income (annual)"

*Generating INC_PEN variable*
*------------------------------
*penins includes income from pensions and insurance as derived from "mnthin19" variable*
gen INC_PEN=penins
lab val INC_PEN INC_PEN
lab var INC_PEN "Pensions/social assistance (annual)"

*Generating INC_STUDY variable*
*-------------------------------
gen INC_STUDY=.
lab val INC_STUDY INC_STUDY
lab var INC_STUDY "Study support (annual)"

*Generating INC_OTH variable*
*------------------------------
gen INC_OTH=incother
lab val INC_OTH INC_OTH
lab var INC_OTH "Other income (annual)"

keep HID INC_WAGE INC_SOCA INC_FARM_G INC_NFARM_G INC_RENT INC_FIN INC_PEN INC_STUDY INC_OTH 

*Merging with 04_AGGDATA\ETH_2000_H.dta*
*------------------------------------------
sort HID
merge HID using 04_AGGDATA\ETH_2000_H.dta
tab _merge  /*_merge=1 (660 observations),_merge=3 (16,672 observations)*/
drop if _merge==1
drop _merge

*Generating INC_TOT_G variable*
*--------------------------------
egen INC_TOT_G=rowtotal (INC_RMT INC_WAGE INC_SOCA INC_FARM_G INC_NFARM_G INC_RENT INC_FIN INC_PEN INC_STUDY INC_OTH)
lab val INC_TOT_G INC_TOT_G
lab var INC_TOT_G "Total gross household income (annual)"

keep COUNTRY REGION PROVINCE DISTRICT HID SURVEYR RURURB HHSIZE HHSIZE_S WTA_HH ///
	WTA_POP HHSEX HHAGEY HHMARST HHEDLEV /*HHEMSTAT HHEMPTYPE HHINDUSTRY*/ OWNHOUSE ROOMS ///
	ROOF WALLS FLOOR WATER ADISWAT ATIMWAT ELECTCON FUELCOOK FUELLIGH TOILET GARBDISP DISPSCH ///
	DISPSCH1 TIMPSCH TIMPSCH1 DISHEAL DISHEAL1 TIMHEAL TIMHEAL1 AGLAND AGLNDOW OTHLNDOW LANDSIZE ///
	AREA_IRRIG AREA_NONIRRIG AREA_COLLAT LANDCON RADIO TV PHONE CPHONE INTERNET FRIDGE SEWMACH ///
	COMPUTER STOVE OXCART BCYCLE BOAT MCYCLE CAR LLIVESK MLIVESK POULTRY PCEXP PCEXP_PPP ///
	QUINTILE_N QUINTILE_RU QUINTILE_URB QUINTILE_R_U SEX_RMT_1 SEX_RMT_2 SEX_RMT_3 RELAT_RMT_1 ///
	RELAT_RMT_2 RELAT_RMT_3 DES_MIG_1 DES_MIG_2 DES_MIG_3 ORIGIN_RMT AMT_RMT_1 AMT_RMT_2 ///
	AMT_RMT_3 INC_RMT INC_WAGE INC_SOCA INC_FARM_G INC_NFARM_G INC_RENT INC_FIN INC_PEN ///
	INC_STUDY INC_OTH INC_TOT_G ///

order COUNTRY REGION PROVINCE DISTRICT HID SURVEYR RURURB HHSIZE HHSIZE_S WTA_HH ///
	WTA_POP HHSEX HHAGEY HHMARST HHEDLEV /*HHEMSTAT HHEMPTYPE HHINDUSTRY*/ OWNHOUSE ROOMS ///
	ROOF WALLS FLOOR WATER ADISWAT ATIMWAT ELECTCON FUELCOOK FUELLIGH TOILET GARBDISP DISPSCH ///
	DISPSCH1 TIMPSCH TIMPSCH1 DISHEAL DISHEAL1 TIMHEAL TIMHEAL1 AGLAND AGLNDOW OTHLNDOW LANDSIZE ///
	AREA_IRRIG AREA_NONIRRIG AREA_COLLAT LANDCON RADIO TV PHONE CPHONE INTERNET FRIDGE SEWMACH ///
	COMPUTER STOVE OXCART BCYCLE BOAT MCYCLE CAR LLIVESK MLIVESK POULTRY PCEXP PCEXP_PPP ///
	QUINTILE_N QUINTILE_RU QUINTILE_URB QUINTILE_R_U SEX_RMT_1 SEX_RMT_2 SEX_RMT_3 RELAT_RMT_1 ///
	RELAT_RMT_2 RELAT_RMT_3 DES_MIG_1 DES_MIG_2 DES_MIG_3 ORIGIN_RMT AMT_RMT_1 AMT_RMT_2 ///
	AMT_RMT_3 INC_RMT INC_WAGE INC_SOCA INC_FARM_G INC_NFARM_G INC_RENT INC_FIN INC_PEN ///
	INC_STUDY INC_OTH INC_TOT_G ///

count  /*17,318 observations (households)*/
sort HID
save 04_AGGDATA\ETH_2000_H.dta, replace



				  
