*HARMONIZED INDIVIDUAL-LEVEL FILE*
*____________________________________

*Generating ETH_2000_I.dta*
*---------------------------

*Section 1.1: Sample, Geography and Basic Household Identifier*
*-----------------------------------------------------------------

clear
set mem 500m
set more off
						
cd "C:\AFRCE\Ethiopia 2000"
use "02_CLEANDATA\ur20_1st.dta",clear

des /*initial number of observations is 79,622*/

sort HID
codebook HID  /*17,332 observations*/

*Generating DISTRICT variable*
*--------------------------------
gen DISTRICT=wereda
lab val DISTRICT DISTRICT
lab var  DISTRICT "District code"


*Generating PROVINCE variable*
*-------------------------------
recode killil (12=8) (13=9) (14=10) (15=11)
lab val killil killil
label def killil 1 "Tigray" 2 "Afar" 3 "Amhara" 4 "Oromiya" 5"Somali" 6 "Benishangul" 7 "SNNPRG" 8 "Gambela" 9 "Harari" 10 "Addis Ababa" 11 "Dire Dawa",replace
gen PROVINCE=killil
lab val PROVINCE PROVINCE
lab var PROVINCE "Province code"

keep HID DISTRICT PROVINCE

collapse DISTRICT PROVINCE,by (HID)

count  /*17,332 observations (households)*/

*Merging with 00_ETH_BASICINFO.dta*
*-----------------------------------
sort HID
merge HID using 04_AGGDATA\00_ETH_BASICINFO.dta, keep (COUNTRY REGION SURVEYR RURURB HHSIZE HHSIZE_S WTA_HH WTA_POP)
tab _merge /*_merge=1 (660 observations), _merge=3 (16,672 observations)*/
drop if _merge==1
drop _merge

count /*16,672 observations (households)*/

sort HID

save "04_AGGDATA\ETH_2000_I.dta", replace
*-----------------------------------------------------------------

*Section 1.2: Generating Basic Demographic Characteristics*
*-----------------------------------------------------------

use "02_CLEANDATA\ur20_1st.dta", clear

des  /*number of initial observations is 79,622*/

/*NOTE: First thing to do in this dataset is to recode the killil variable to match 
the code of the same variables in the hhice.dta dataset which led to 
04_AGGDATA\00_ETH_BASICINFO. This is a necessary step to allow for a successful merging
of the datasets*/

recode killil (12=8) (13=9) (14=10) (15=11)
lab val killil killil
label def killil 1 "Tigray" 2 "Afar" 3 "Amhara" 4 "Oromiya" 5"Somali" 6 "Benishangul" 7 "SNNPRG" 8 "Gambela" 9 "Harari" 10 "Addis Ababa" 11 "Dire Dawa",replace

*Checking*
tab killil
tab killil,nol

sort HID
codebook HID  /*17,332 observations (households)*/

*Renaming variable indiv_id to INDID*
*---------------------------------------
rename indiv_id INDID
lab val INDID INDID
label var INDID "Individual identification"

*Checking that HHH is assigned an INDID=1 as stated in reference manual*
tab INDID relation,m 
*In total there are 17,332 HHs while there are 16,672 HHHs* 
* out of the 16,672 HHs, 16,669 HHHs are assigned an INDID=1 and 3 HHHs are assigned an INDID=2*
*therefore, there are 660 households with no household heads*
*cross-tabulation between "INDID" and "relation" also shows 2 individuals with "not stated" relationship to household head are assigned an INDID=1*/

*Generating SEX variable*
*--------------------------
recode sex (2=0)
gen SEX=sex
lab val SEX SEX
lab def SEX 1 "Male" 0 "Female",replace
lab var SEX "Sex"

*Generating RELAT variable*
*---------------------------
*First check if there are multilple household heads*
sort HID
bysort HID:egen multiplehhh=count (relation) if relation==0
tab multiplehhh /*shows no multiple household heads*/
drop multiplehhh

*NOTE: no grandchild is identified in dataset*
gen RELAT=1 if relation==0
replace RELAT=2 if relation==1
replace RELAT=3 if [relation==2|relation==3|relation==4] 
*assume that son/daughter of spouse is also son/daughter of household head and son/daughter of householdhead is also son/daughter of spouse*
replace RELAT=4 if relation==5 
*no "grandchild" identified in dataset so there is no relat==5*
*no son/daughter-in-law identified in dataset so there is no relat==6*
replace RELAT=7 if [relation==6| relation==7] /*brother/sister of head/spouse will be under "other relative" category*/
*no donestic help/paying boarder identified in dataset so no relat=8*
replace RELAT=9 if [relation==8|relation==9]

lab val RELAT RELAT
lab def RELAT 1 "Head" 2 "Spouse" 3 "Child" 4 "Father/Mother" 5 "Grandchild" 6 "Son-in-law/daughter-in-law" 7 "Other relative" 8 "Domestic help/paying boarder" 9 "Non-relative"
lab var RELAT "Relationship to household Head"

*Generating HEAD variable*
*----------------------------
gen HEAD=.
replace HEAD=0 if [relation==1|relation==2|relation==3|relation==4|relation==5|relation==6|relation==7|relation==8|relation==9]
replace HEAD=1 if relation==0
lab val HEAD HEAD
lab def HEAD 0 "No" 1 "Yes"
lab var HEAD "Household head"

*Generating MARSTAT variable*
*--------------------------------
*Checking for presence of multiple spouses in a household*
bysort HID:egen marriedmultiple=count (relation) if relation==1 /*counting for presence of more than one spouse in the household*/
*above command assigns the values only to spouse*

*Assigning marriedmultiple value also for each HHH in a HH which has a spouse*
egen marriedmultiple1=mean(marriedmultiple) if [relation==0|relation==1],by (HID) 

tab marriedmultiple /*shows that there are some households having 2,3,4,5 spouses*/
codebook HID if marriedmultiple==1 /*10,206 households with 1 spouse in each household*/
codebook HID if marriedmultiple==2 /*111 households with 2 spouses in each household*/
codebook HID if marriedmultiple==3 /*6 households with 3 spouses in each household*/
codebook HID if marriedmultiple==4 /*4 households with 4 spouses in each household*/
codebook HID if marriedmultiple==5 /*1 household with 5 spouses in each household*/

/*cross tabulating to see if there is any inconsistency between relation 
(relationship to household head) and marital (marital status)*/

tab relation marital /*shows that all spouses have a "currently married" status*/

gen MARSTAT=1 if marital==1
replace MARSTAT=2 if marital==2 & marriedmultiple1==1 & [relation==0|relation==1]
replace MARSTAT=3 if marital==2 & [marriedmultiple1==2|marriedmultiple1==3|marriedmultiple1==4|marriedmultiple1==5] & [relation==0|relation==1]
/*no information in dataset to differentiate between different types of union
so marstat=4 will not be defined in marstat variable*/
replace MARSTAT=5 if [marital==3|marital==4] & [relation==0|relation==1]
replace MARSTAT=6 if marital==5 & [relation==0|relation==1]
lab val MARSTAT MARSTAT
lab def MARSTAT 1 "Never married" 2 "Married monogamous" 3 "Married polygamous" 4 "Common law,union coutumiere,union libre,living together" 5 "Divorced/Separated" 6 "Widowed"
lab var MARSTAT "Marital status"

*Generating SP_PRES variable*
*----------------------------
gen SP_PRES=.
lab val SP_PRES SP_PRES
lab var SP_PRES "Spouse present"

*Generating AGEY variable*
*---------------------------
*NOTE: age variable is only given in years and not months so checking for consistency with age in months to get correct age in completed years is not possible*
recode age (99=98)
gen AGEY=age
lab val AGEY AGEY
label var AGEY "Age in completed years"

*Generating ETHNICITY variable*
*-------------------------------
gen ETHNICITY=.
lab val ETHNICITY ETHNICITY
label var ETHNICITY "Ethnicity"
  
*Generating LANGUAGE variable*
*---------------------------------
gen LANGUAGE=.
lab val LANGUAGE LANGUAGE
label var LANGUAGE "Language"

*Generating RELIGION variable*
*--------------------------------
gen RELIGION=.
lab val RELIGION RELIGION
lab var RELIGION "Religion"

keep HID INDID SEX RELAT HEAD MARSTAT SP_PRES AGEY ETHNICITY LANGUAGE RELIGION

sort HID
merge HID using "04_AGGDATA\ETH_2000_I.dta"
tab _merge /*_merge=1 (660 observations),_merge=3 (78,962 observations)*/
drop if _merge==1
drop _merge

count  /*78,962 observations*/
codebook HID /*16,672 households*/

sort HID INDID

save 04_AGGDATA\ETH_2000_I.dta, replace
*----------------------------------------------------------------------------------------

*Section 2.3: Literacy and Education*
*--------------------------------------

use "02_CLEANDATA\ur20_1st.dta", clear

count /*79,622 observations (individuals)*/

sort HID
codebook HID /*17,332 households*/

*Renaming variable indiv_id to INDID*
*--------------------------------------
rename indiv_id INDID
lab val INDID INDID
label var INDID "Individual identification"

sort HID INDID

*Generating LITERACY variable*
*-------------------------------
gen LITERACY=.
replace LITERACY=1 if read_wri==1 & age>=5
replace LITERACY=2 if read_wri==2 & age>=5
lab val LITERACY LITERACY
lab def LITERACY 1 "Can read & write" 2 "Cannot read or write" 3 "Cannot be determined"
lab var LITERACY "Literacy status"

*Generating EVERATTD  variable*
*--------------------------------
/*there is no variable which explicitly captures "EVERATTD" variable. However, the variable can
be derived using the variable which captures highest grade completed as well as using the variable
which captures literacy*/
gen EVERATTD=.
replace EVERATTD=1 if [grade_co>=0 & grade_co<=88] & age>=5
replace EVERATTD=0 if read_wri==2 & age>=5
lab val EVERATTD EVERATTD
lab def EVERATTD 1 "Yes" 0 "No",replace
lab var EVERATTD "Ever attended school"

*CHECK*
tab EVERATTD,m
tab grade_co EVERATTD,m

*Generating ATSCHOOL variable*
*------------------------------
/*NOTE:There is no variable to capture enrollment over past 12 months.
*Instead there is variable "regi_att" which captures whether an individual is currently
registered to attend school. So "regi_att" is used to generate ATSCHOOL variable*/

gen ATSCHOOL=.
replace ATSCHOOL=1 if regi_att==1 
replace ATSCHOOL=0 if regi_att==2 
lab val ATSCHOOL ATSCHOOL
lab def ATSCHOOL 1 "Yes" 0 "No"
lab var ATSCHOOL "Currently enrolled in school"

*CHECK*
tab ATSCHOOL,m 
*no=49,413 observations, yes=17,997 observations, 12,212 missing observations*

tab ATSCHOOL EVERATTD, m

replace ATSCHOOL=0 if ATSCHOOL==. & EVERATTD!=. /*4 changes made*/
/*3,159 individuals responded that they were in school but had never attended school
For these observations EVERATTD is recoded to 1 (YES)*/
replace EVERATTD=1 if EVERATTD==0 & ATSCHOOL==1
tab	ATSCHOOL, miss
*CHECK: Consistently coded: 12,212 missing values

*Generating EDLEVEL_AR variable*
*---------------------------------
*highest education level completed for those who are currently in school*
gen EDLEVEL_AR=.
replace EDLEVEL_AR=0 if grade_co==88 & ATSCHOOL==1 
replace EDLEVEL_AR=1 if grade_co==1 & ATSCHOOL==1 
replace EDLEVEL_AR=1 if (grade_co>=2 & grade_co<=8) & ATSCHOOL==1 
replace EDLEVEL_AR=2 if (grade_co<=9 & grade_co<=10) & ATSCHOOL==1 
replace EDLEVEL_AR=3 if (grade_co>=11 & grade_co<=12) & ATSCHOOL==1 
replace EDLEVEL_AR=4 if grade_co>=13 & ATSCHOOL==1 
replace EDLEVEL_AR=6 if grade_co>=14 & ATSCHOOL==1 

*highest education level completed for those who are not currently in school*
replace EDLEVEL_AR=0 if grade_co==88 & ATSCHOOL==0 
replace EDLEVEL_AR=1 if grade_co==0 & ATSCHOOL==0 
replace EDLEVEL_AR=1 if (grade_co>=1 & grade_co<=7) & ATSCHOOL==0 
replace EDLEVEL_AR=2 if (grade_co>=8 & grade_co<=9) & ATSCHOOL==0 
replace EDLEVEL_AR=3 if (grade_co>=10 & grade_co<=11) & ATSCHOOL==0 
replace EDLEVEL_AR=4 if (grade_co>=12 & grade_co<=13) & ATSCHOOL==0 
replace EDLEVEL_AR=6 if (grade_co>=12 & grade_co<=14) & ATSCHOOL==0 

lab val EDLEVEL_AR EDLEVEL_AR
lab def EDLEVEL_AR 0 "No Education" ///
	1 "Pre-school/Primary,not completed" ///
	2 "Completed primary,but less than completed lower secondary" ///
	3 "Completed lower secondary(or post-primary vocational education)but less than completed upper secondary" ///
	4 "Completed upper secondary (or extended vocational/technical education)" ///
	5 "Post secondary technical" ///
	6 "University and higher" ///
	8 "Formal adult education or literacy" ///
	9 "Other"
	
lab var EDLEVEL_AR "Highest level of education completed"


*Generating EDYEARS_AT variable*
*---------------------------------
*Years of education for those who are currently attending school*

gen EDYEARS_AT=.
*EDYEARS_AT from pre-school to grade 12*
replace EDYEARS_AT=0 if (grade_co==0|grade_co==88) & ATSCHOOL==1 
replace EDYEARS_AT=1 if grade_co==1 & ATSCHOOL==1 
replace EDYEARS_AT=2 if grade_co==2 & ATSCHOOL==1 
replace EDYEARS_AT=3 if grade_co==3 & ATSCHOOL==1 
replace EDYEARS_AT=4 if grade_co==4 & ATSCHOOL==1 
replace EDYEARS_AT=5 if grade_co==5 & ATSCHOOL==1 
replace EDYEARS_AT=6 if grade_co==6 & ATSCHOOL==1 
replace EDYEARS_AT=7 if grade_co==7 & ATSCHOOL==1 
replace EDYEARS_AT=8 if grade_co==8 & ATSCHOOL==1 
replace EDYEARS_AT=9 if grade_co==9 & ATSCHOOL==1 
replace EDYEARS_AT=10 if grade_co==10 & ATSCHOOL==1 
replace EDYEARS_AT=11 if grade_co==11 & ATSCHOOL==1 
replace EDYEARS_AT=12 if grade_co==12 & ATSCHOOL==1 
*EDYEARS_AT for "certificate"(1 year after 12th grade)*
replace EDYEARS_AT=13 if grade_co==13 & ATSCHOOL==1 
*EDYEARS_AT for "college/university"(4 years after 12th grade)*
replace EDYEARS_AT=16 if grade_co==14 & ATSCHOOL==1 

lab val EDYEARS_AT EDYEARS_AT
lab var EDYEARS_AT "Years of education for currently enrolled"

*Generating EDYEARS variable*
*------------------------------
*Years of education for those who are not currently attending school*

*EDYEARS from pre-school to grade 12*
gen EDYEARS=.
replace EDYEARS=0 if (grade_co==0|grade_co==88) & ATSCHOOL==0 
replace EDYEARS=1 if grade_co==1 & ATSCHOOL==0 
replace EDYEARS=2 if grade_co==2 & ATSCHOOL==0 
replace EDYEARS=3 if grade_co==3 & ATSCHOOL==0 
replace EDYEARS=4 if grade_co==4 & ATSCHOOL==0 
replace EDYEARS=5 if grade_co==5 & ATSCHOOL==0 
replace EDYEARS=6 if grade_co==6 & ATSCHOOL==0 
replace EDYEARS=7 if grade_co==7 & ATSCHOOL==0 
replace EDYEARS=8 if grade_co==8 & ATSCHOOL==0 
replace EDYEARS=9 if grade_co==9 & ATSCHOOL==0 
replace EDYEARS=10 if grade_co==10 & ATSCHOOL==0 
replace EDYEARS=11 if grade_co==11 & ATSCHOOL==0 
replace EDYEARS=12 if grade_co==12 & ATSCHOOL==0 
*EDYEARS_AT for "certificate"(1 year after 12th grade)*
replace EDYEARS=13 if grade_co==13 & ATSCHOOL==0 
*EDYEARS_AT for "college/university"(4 years after 12th grade)*
replace EDYEARS=16 if grade_co==14 & ATSCHOOL==0 

*for those who are currently in school*
*subtract one level for those currently attending*

*EDYEARS_AT from pre-school to grade 12*
replace EDYEARS=0 if (grade_co==0|grade_co==88) & ATSCHOOL==1 
replace EDYEARS=0 if grade_co==1 & ATSCHOOL==1 
replace EDYEARS=1 if grade_co==2 & ATSCHOOL==1 
replace EDYEARS=2 if grade_co==3 & ATSCHOOL==1 
replace EDYEARS=3 if grade_co==4 & ATSCHOOL==1 
replace EDYEARS=4 if grade_co==5 & ATSCHOOL==1 
replace EDYEARS=5 if grade_co==6 & ATSCHOOL==1 
replace EDYEARS=6 if grade_co==7 & ATSCHOOL==1 
replace EDYEARS=7 if grade_co==8 & ATSCHOOL==1 
replace EDYEARS=8 if grade_co==9 & ATSCHOOL==1 
replace EDYEARS=9 if grade_co==10 & ATSCHOOL==1 
replace EDYEARS=10 if grade_co==11 & ATSCHOOL==1 
replace EDYEARS=11 if grade_co==12 & ATSCHOOL==1 
*EDYEARS_AT for "certificate"(1 year after 12th grade)*
replace EDYEARS=12 if grade_co==13 & ATSCHOOL==1 
*EDYEARS_AT for "college/university"(4 years after 12th grade)*
replace EDYEARS=14 if grade_co==14 & ATSCHOOL==1 

lab val EDYEARS EDYEARS
lab var EDYEARS "Years of completed education"

*Generating SCHLTYP*
*--------------------
gen SCHLTYP=.
replace SCHLTYP=1 if type_sch==1
replace SCHLTYP=2 if [type_sch==2|type_sch==3|type_sch==4]
replace SCHLTYP=9 if [type_sch==5|type_sch==6|type_sch==9]
lab def SCHLTYP 1 "Public" 2 "Private" 9 "Other",replace
lab var SCHLTYP "Type of school attending"

sort HID INDID

keep HID INDID LITERACY EVERATTD ATSCHOOL EDLEVEL_AR EDYEARS_AT EDYEARS SCHLTYP

merge HID INDID using "04_AGGDATA\ETH_2000_I.dta"
tab _merge /*_merge=1 (660 observations),_merge=3 (78,962 observations)*/
drop if _merge==1
drop _merge

count  /*78,962 observations (individuals)*/
codebook HID  /*16,672 households*/

sort HID INDID

save 04_AGGDATA\ETH_2000_I, replace
*---------------------------------------------------------------------------------

*Section 2.4: Health*
*---------------------
use "02_CLEANDATA\ur20_1st.dta", clear

count /*979,622 observations (individuals)*/

sort HID
codebook HID /*17,332 households*/

*Renaming variable indiv_id to INDID*
*--------------------------------------
rename indiv_id INDID
lab val INDID INDID
label var INDID "Individual identification"

sort HID INDID

*Generating variable MORB_TR*
*-----------------------------
gen MORB_TR= 8
label var MORB_TR "Time reference for variable MORBID (weeks)"

*Generating MORBID variable*
*------------------------------
gen MORBID=.
replace MORBID=1 if healt_p==1
replace MORBID=0 if healt_p==2
lab val MORBID MORBID
lab def MORBID 1 "Yes" 0 "No",replace
lab var MORBID "Morbidity last MORB_TR"

*Generating RTREATM variable*
*-------------------------------
tab MORBID get_heal /*checking that only individuals with morbid=1 are included in this cross-tabulation*/
/*result of above cross-tabulation shows 10,468 individuals who were sick during the past two months sought medical attention and 9,677 individuals did not seek medical attention*/

gen RTREATM=.
replace RTREATM=1 if MORBID==1 & get_heal==1
replace RTREATM=0 if MORBID==1 & get_heal==2
lab val RTREATM RTREATM
lab def RTREATM 1 "Yes" 0 "No",replace
lab var RTREATM "Sought medical attention"

tab RTREATM 
*tabulation shows that only individuals with MORBID=1 are included in RTREATM*

*Generating HLTHFAC variable*
*----------------------------
gen HLTHFAC=.
replace HLTHFAC=1 if [from_wh==1|from_wh==5] 
replace HLTHFAC=2 if from_wh==3
replace HLTHFAC=3 if [from_wh==2|from_wh==4|from_wh==7]
replace HLTHFAC=4 if from_wh==6 
replace HLTHFAC=5 if from_wh==9
replace HLTHFAC=6 if from_wh==10
replace HLTHFAC=9 if [from_wh==8|from_wh==11]
lab val HLTHFAC HLTHFAC
lab def HLTHFAC 1 "Hospital" 2 "Clinics" 3 "Dispensary, health center, health post" 4 "Outreach" 5 "Pharmacy" 6 "Traditional healer" 9 "Other"
lab var HLTHFAC "Health provider visited"

*Generating OWHPROVD variable*
*-------------------------------
gen OWHPROVD=1 if [from_wh==1|from_wh==2|from_wh==3|from_wh==4]
replace OWHPROVD=2 if [from_wh==5|from_wh==8]
replace OWHPROVD=3 if from_wh==10
replace OWHPROVD=4 if from_wh==6
replace OWHPROVD=9 if [from_wh==7|from_wh==11|from_wh==9]
lab val OWHPROVD OWHPROVD
lab def OWHPROVD 1 "Public" 2 "Private-modern medicine" 3 "Private-traditional healers" 4 "Missionary/NGO" 9 "Other"
lab var OWHPROVD "Ownership of health provider visited"

keep HID INDID MORB_TR MORBID RTREATM HLTHFAC OWHPROVD

sort HID INDID
merge HID INDID using "04_AGGDATA\ETH_2000_I.dta"
tab _merge /*_merge=1 (660 observations),_merge=3(78,962 observations)*/
drop if _merge==1
drop _merge

count  /*78,962 observations*/
codebook HID  /*16,672 households*/

sort HID INDID

save 04_AGGDATA\ETH_2000_I.dta, replace
*----------------------------------------------------------------------------------------

*Section 1.5:Child Survival and Anthropometry for Children Aged 0-59 Months*
*----------------------------------------------------------------------------

use "02_CLEANDATA\ur20_1st.dta", clear

count /*979,622 observations (individuals)*/

codebook HID /*17,332 households*/

*Renaming variable indiv_id to INDID*
*--------------------------------------
rename indiv_id INDID
lab val INDID INDID
label var INDID "Individual identification"
			  
*Generating AGEM variable*
*----------------------------
replace agechild=. if agechild==99
gen AGEM=agechild
lab val AGEM AGEM 
lab var AGEM "Age of child in completed months"

*Generating WHDELIV variable*
*------------------------------
gen WHDELIV=.
lab val WHDELIV WHDELIV
lab def WHDELIV 1 "Trained birth attendant" 2 "Traditional birth attendant" 3 "Relative/friend" 9 "Other",replace
lab var WHDELIV "Who helped assist child birth"

*Generating VCARD variable*
*---------------------------
gen VCARD=.
lab val VCARD VCARD
lab def VCARD 1 "Yes" 2 "No, but child has been vaccinated" 3 "No,child never vaccinated"
lab var VCARD "Child has vaccine card"

*Generating variable BCG*
*--------------------------
recode bcg (2=0) (3=9)
gen BCG=bcg
lab val BCG BCG
lab def BCG 1 "Yes" 0 "No"
lab var BCG "Child immunized against BCG"

*Generating POLIO_DO variable*
*------------------------------
gen POLIO_DO=.
label val POLIO_DO POLIO_DO
label def POLIO_DO 0"No dose" 1"One dose" 2 "Two doses" 3 "Three doses" 4 "More than three doses" 9 "Unspecified number of doses"
label var POLIO_DO "Number of doses of polio received"

*Generating DPT_DOSE variable*
*------------------------------
gen DPT_DOSE=.
label val DPT_DOSE DPT_DOSE
label def DPT_DOSE 0 "No dose" 1 "One dose" 2 "Two doses" 3 "Three doses" 4 "More than three doses" 9 "Unspecified numver of doses",replace
label var DPT_DOSE "Number of doses of DPT received"

*Generating MEASLES variable*
*------------------------------
replace mselses=. if mselses==9
recode mselses (2=0) (3=9)
gen MEASLES=1 if mselses==1
replace MEASLES=0 if mselses==0
replace MEASLES=9 if mselses==9
lab val MEASLES MEASLES
lab def MEASLES 1 "Yes" 0 "No" 9 "Don't know"
lab var MEASLES "Child immunized against measles"

*Generating VACCINE variable*
*-------------------------------
gen VACCINE=.
lab val VACCINE VACCINE
lab def VACCINE 1 "Fully immunized" 2 "Partialy immunized" 3 "Immunized but no information on completeness" 4 "Not immunized",replace
lab var VACCINE "Immunization status of child"

*Generating WEIGHT variable*
*-----------------------------
replace weight=. if weight==99999
gen WEIGHT=weight/1000 if AGEM<=59
label var WEIGHT "Weight of child(kg)"

*Generating HEIGHT variable*
*-----------------------------
replace height=. if height==999
gen HEIGHT=height
label var HEIGHT "Height of child(cms)"

keep HID INDID AGEM WHDELIV VCARD BCG POLIO_DO DPT_DOSE MEASLES VACCINE WEIGHT HEIGHT 

sort HID INDID
merge HID INDID using "04_AGGDATA\ETH_2000_I.dta"
tab _merge /*_merge=1 (660 observations), _merge=3(78,962 observations)*/
drop if _merge==1
drop _merge

count /*78,962 observations*/
codebook HID  /*16,672 households*/

order COUNTRY REGION PROVINCE DISTRICT HID SURVEYR RURURB HHSIZE HHSIZE_S WTA_HH WTA_POP INDID ///
	SEX RELAT HEAD MARSTAT SP_PRES AGEY ETHNICITY LANGUAGE RELIGION LITERACY EVERATTD ///
	ATSCHOOL EDLEVEL_AR EDYEARS EDYEARS_AT SCHLTYP MORB_TR MORBID RTREATM HLTHFAC OWHPROVD ///
	AGEM WHDELIV VCARD BCG POLIO_DO DPT_DOSE MEASLES VACCINE WEIGHT HEIGHT ///

sort HID INDID

save 04_AGGDATA\ETH_2000_I.dta, replace


